==> analytics-modeling-server-2.5-sources.jar: org/odpi/openmetadata/accessservices/analyticsmodeling/utils/Constants.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */

package org.odpi.openmetadata.accessservices.analyticsmodeling.utils;

public class Constants {

	public static final Integer PAGE_SIZE = 100;
	public static final Integer START_FROM = 0;
	public static final String ADDITIONAL_PROPERTIES = "additionalProperties";
	public static final String ANALYTICS_MODELING_OMAS_NAME = "AnalyticsModelingOmas";
	public static final String ANALYTICS_MODELING_USER_ID = "AnalyticsModelingOmas";
	public static final String ASSET_SCHEMA_TYPE = "AssetSchemaType";
	public static final String ATTACHED_NOTE_LOG = "AttachedNoteLog";
	public static final String ATTRIBUTE_FOR_SCHEMA = "AttributeForSchema";
	public static final String ATTRIBUTE_NAME = "name";
	public static final String DATABASE = "Database";
	public static final String DATA_CONTENT_FOR_DATASET = "DataContentForDataSet";
	public static final String DATA_UNDERSCORE_TYPE = "data_type";
	public static final String DEPLOYED_DATABASE_SCHEMA = "DeployedDatabaseSchema";
	public static final String DISPLAY_NAME = "displayName";
	public static final String FOREIGN_KEY = "ForeignKey";
	public static final String GUID = "guid";
	public static final String IS_NULLABLE = "isNullable";
	public static final String LENGTH = "length";
	public static final String NAME = "name";
	public static final String NESTED_SCHEMA_ATTRIBUTE = "NestedSchemaAttribute";
	public static final String NOTE_LOG = "NoteLog";
	public static final String ODBC_TYPE = "odbc_type";
	public static final String OWNER_TYPE = "ownerType";
	public static final String PATCH_LEVEL = "patchLevel";
	public static final String POSITION = "position";
	public static final String PRIMARY_KEY = "PrimaryKey";
	public static final String QUALIFIED_NAME = "qualifiedName";
	public static final String RELATIONAL_COLUMN = "RelationalColumn";
	public static final String RELATIONAL_COLUMN_TYPE = "RelationalColumnType";
	public static final String RELATIONAL_DB_SCHEMA_TYPE = "RelationalDBSchemaType";
	public static final String RELATIONAL_TABLE = "RelationalTable";
	public static final String SCHEMA_ASSET = "SchemaAsset";
	public static final String SOURCE = "source";
	public static final String TYPE = "type";
	public static final String TYPE_SUFFIX = "_type";
	public static final String USER_ID = "userId";
	public static final String VERSION = "version";
	public static final String ZONE_MEMBERSHIP = "zoneMembership";	
}

==> analytics-modeling-server-2.8-sources.jar: org/odpi/openmetadata/accessservices/analyticsmodeling/utils/Constants.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */

package org.odpi.openmetadata.accessservices.analyticsmodeling.utils;

public class Constants {

	public static final Integer PAGE_SIZE = 100;
	public static final Integer START_FROM = 0;
	public static final String ADDITIONAL_PROPERTIES = "additionalProperties";
	public static final String ANALYTICS_MODELING_OMAS_NAME = "AnalyticsModelingOmas";
	public static final String ANALYTICS_MODELING_USER_ID = "AnalyticsModelingOmas";
	public static final String ASSET_SCHEMA_TYPE = "AssetSchemaType";
	public static final String ATTACHED_NOTE_LOG = "AttachedNoteLog";
	public static final String ATTRIBUTE_FOR_SCHEMA = "AttributeForSchema";
	public static final String ATTRIBUTE_NAME = "name";
	public static final String DATABASE = "Database";
	public static final String DATA_CONTENT_FOR_DATASET = "DataContentForDataSet";
	public static final String DATA_UNDERSCORE_TYPE = "data_type";
	public static final String DEPLOYED_DATABASE_SCHEMA = "DeployedDatabaseSchema";
	public static final String DISPLAY_NAME = "displayName";
	public static final String FOREIGN_KEY = "ForeignKey";
	public static final String GUID = "guid";
	public static final String IS_NULLABLE = "isNullable";
	public static final String LENGTH = "length";
	public static final String NAME = "name";
	public static final String NESTED_SCHEMA_ATTRIBUTE = "NestedSchemaAttribute";
	public static final String NOTE_LOG = "NoteLog";
	public static final String ODBC_TYPE = "odbc_type";
	public static final String OWNER_TYPE = "ownerType";
	public static final String PATCH_LEVEL = "patchLevel";
	public static final String POSITION = "position";
	public static final String PRIMARY_KEY = "PrimaryKey";
	public static final String QUALIFIED_NAME = "qualifiedName";
	public static final String RELATIONAL_COLUMN = "RelationalColumn";
	public static final String RELATIONAL_COLUMN_TYPE = "RelationalColumnType";
	public static final String RELATIONAL_DB_SCHEMA_TYPE = "RelationalDBSchemaType";
	public static final String RELATIONAL_TABLE = "RelationalTable";
	public static final String SCHEMA_ASSET = "SchemaAsset";
	public static final String SOURCE = "source";
	public static final String SYNC_DATA_TYPE = "datatype";	
	public static final String SYNC_DESCRIPTION = "description";	
	public static final String SYNC_EXPRESSION = "expression";
	public static final String SYNC_IDENTIFIER = "identifier";
	public static final String SYNC_ID_LIST_DELIMITER = "\t";
	public static final String SYNC_NATIVE_CLASS = "nativeClass";
	public static final String TYPE = "type";
	public static final String TYPE_SUFFIX = "_type";
	public static final String USER_ID = "userId";
	public static final String VERSION = "version";
	public static final String ZONE_MEMBERSHIP = "zoneMembership";
}
